//
//  YHHomePageViewController.swift
//  galaxy
//
//  Created by davidhuangA on 2024/4/8.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import ESPullToRefresh
import GKNavigationBarSwift

class YHHomePageViewController: YHBaseViewController {
    var viewModel: YHHomePageViewModel!
    
    lazy var items = {
        return [AboutAdvantageItem(iconName: "about_match", title: "精准匹配", detail: "大数据精准匹配，专属方案获批率更高", url: "")]
    }()
    
    lazy var homeCollectView = {
//        // 设置布局方向
//        let flowLayout = UICollectionViewFlowLayout()
//        let margin = 20.0
//        let gap = 20.0
//        let itemWidth = ceil((KScreenWidth - 2*margin - gap)/2.0)
//        flowLayout.itemSize = CGSize(width: itemWidth, height: 210 + 87 + 4)
//        flowLayout.minimumInteritemSpacing = 10.0
//        flowLayout.minimumLineSpacing = 10.0
//        flowLayout.scrollDirection = .vertical
//        
//        let collectinoView = UICollectionView(frame: .zero, collectionViewLayout: flowLayout)
//        collectinoView.backgroundColor = .white
//        collectinoView.register(YHDavidTestCollectionViewCell.self, forCellWithReuseIdentifier:YHDavidTestCollectionViewCell.cellReuseIdentifier)
//        collectinoView.delegate = self
//        collectinoView.dataSource = self
//        collectinoView.showsVerticalScrollIndicator = false
//        
//        collectinoView.translatesAutoresizingMaskIntoConstraints = false
//        collectinoView.alwaysBounceVertical = true
//
        
        // 设置布局方向
        let flowLayout = YHHomeCollectionLayout()
        flowLayout.minimumInteritemSpacing = 7.0
        flowLayout.minimumColumnSpacing = 10.0
        flowLayout.sectionInset = UIEdgeInsets(top: 0, left: 20, bottom: 0, right: 20)
        
        let collectinoView = YHGestureCollectionView(frame: .zero, collectionViewLayout: flowLayout)
        //        collectinoView.contentInset = UIEdgeInsets(top: 20, left: 20, bottom: 20, right: 20)
        collectinoView.backgroundColor = .white
        collectinoView.register(YHHomeCollectionViewCell.self, forCellWithReuseIdentifier:YHHomeCollectionViewCell.cellReuseIdentifier)
        collectinoView.delegate = self
        collectinoView.dataSource = self
        collectinoView.bounces = false
        collectinoView.translatesAutoresizingMaskIntoConstraints = false
        collectinoView.alwaysBounceVertical = true
        return collectinoView
    }()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        viewModel = YHHomePageViewModel()
        setupUI()
        getData()
    }
    
    lazy var searchView: YHHomeSearchView = {
        let view = YHHomeSearchView()
        let tap = UITapGestureRecognizer(target: self, action: #selector(didSearchBarClicked))
        view.addGestureRecognizer(tap)
        return view
    }()
    
    lazy var homeHeaderView: YHHomeHeadView = {
        let view = YHHomeHeadView()
        return view
    }()
    
    @objc func didSearchBarClicked() {
        let vc = YHSearchInfomationVC()
        self.navigationController?.pushViewController(vc)
    }
    
    func getData() {
        viewModel.getHomeList {[weak self] success, error in
            guard let self = self else { return }
            self.homeCollectView.reloadData()
        }
        viewModel.getHomeBanner(0) {[weak self] success, error in
            guard let self = self else { return }
            self.homeHeaderView.homeBannerView.dataArr = self.viewModel.banners ?? []
        }
        
        viewModel.getHomeClassify {[weak self] success, error in
            guard let self = self else { return }

        }
    }
}

private extension YHHomePageViewController {
    func setupUI() {
        gk_navigationBar.isHidden = true
        view.backgroundColor = .white
        
        view.addSubview(searchView)
        searchView.snp.makeConstraints { make in
            make.top.equalTo(k_Height_safeAreaInsetsTop() + 6)
            make.left.equalTo(20)
            make.right.equalTo(-20)
            make.height.equalTo(YHHomeSearchView.viewH)
        }
        
        view.addSubview(homeCollectView)
        homeCollectView.snp.makeConstraints { make in
            make.left.right.bottom.equalToSuperview()
            make.top.equalTo(searchView.snp.bottom).offset(6)
        }
        
        homeHeaderView.frame = CGRect(x: 20, y: -YHHomeHeadView.viewH, width: KScreenWidth - 40, height: YHHomeHeadView.viewH)
        homeCollectView.addSubview(homeHeaderView)
        homeCollectView.contentInset = UIEdgeInsets(top: YHHomeHeadView.viewH, left: 0, bottom: 0, right: 0)
        
        homeCollectView.es.addInfiniteScrolling {
            self.loadFakeData()
        }
        loadFirstItem()
        homeCollectView.reloadData()
    }
    
    func loadFirstItem() {
        
        DispatchQueue.main.asyncAfter(deadline: .now() + 1) {
            self.items = [AboutAdvantageItem(iconName: "about_match", title: "精准匹配", detail: "大数据精准匹配，专属方案获批率更高", url: ""),AboutAdvantageItem(iconName: "about_match", title: "精准匹配", detail: "大数据精准匹配，专属方案获批率更高", url: ""),AboutAdvantageItem(iconName: "about_match", title: "精准匹配", detail: "大数据精准匹配，专属方案获批率更高", url: ""),AboutAdvantageItem(iconName: "about_match", title: "精准匹配", detail: "大数据精准匹配，专属方案获批率更高", url: "")]
            self.homeCollectView.es.stopPullToRefresh(ignoreDate: true,ignoreFooter: false)
            self.homeCollectView.reloadData()
        }
        
    }
    
    func loadFakeData() {
        DispatchQueue.main.asyncAfter(deadline: .now() + 1) {
            self.items.append(AboutAdvantageItem(iconName: "about_match", title: "精准匹配", detail: "大数据精准匹配，专属方案获批率更高", url: ""))
            self.items.append(AboutAdvantageItem(iconName: "about_match", title: "精准匹配", detail: "大数据精准匹配，专属方案获批率更高", url: ""))
            self.items.append(AboutAdvantageItem(iconName: "about_match", title: "精准匹配", detail: "大数据精准匹配，专属方案获批率更高", url: ""))
            self.items.append(AboutAdvantageItem(iconName: "about_match", title: "精准匹配", detail: "大数据精准匹配，专属方案获批率更高", url: ""))
            self.items.append(AboutAdvantageItem(iconName: "about_match", title: "精准匹配", detail: "大数据精准匹配，专属方案获批率更高", url: ""))
            
            self.homeCollectView.es.stopLoadingMore()
            self.homeCollectView.reloadData()
        }
    }
    
    func getImageSize(_ url: String?) -> CGSize {
        guard let urlStr = url, urlStr.count != 0 else {
            return CGSize.zero
        }
        let tempUrl = URL(string: urlStr)
        let imageSourceRef = CGImageSourceCreateWithURL(tempUrl! as CFURL, nil)
        var width: CGFloat = 0
        var height: CGFloat = 0
        if let imageSRef = imageSourceRef {
            let imageProperties = CGImageSourceCopyPropertiesAtIndex(imageSRef, 0, nil)
            if let imageP = imageProperties {
                let imageDict = imageP as Dictionary
                width = imageDict[kCGImagePropertyPixelWidth] as! CGFloat
                height = imageDict[kCGImagePropertyPixelHeight] as! CGFloat
            }
        }
        return CGSize(width: width, height: height)
    }
}



extension YHHomePageViewController: UICollectionViewDelegate, UICollectionViewDataSource {
    
    func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
        return self.viewModel.lists?.count ?? 0
    }
    
    func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
        let cell = collectionView.dequeueReusableCell(withReuseIdentifier: YHHomeCollectionViewCell.cellReuseIdentifier, for: indexPath) as! YHHomeCollectionViewCell
        cell.listModel = self.viewModel.lists?[indexPath.row]
        return cell
        
    }
    
//    func collectionView(collectionView: UICollectionView, didSelectItemAtIndexPath indexPath: NSIndexPath) {
//        print("index is \(indexPath.row)")
//    }
}


extension YHHomePageViewController : CollectionViewWaterfallLayoutDelegate {
    func collectionView(_ collectionView: UICollectionView, layout: UICollectionViewLayout, sizeForItemAtIndexPath indexPath: NSIndexPath) -> CGSize {
        guard let model = self.viewModel.lists?[indexPath.row] else { return CGSize(width: 0, height: 0) }
        let text = model.title
        let width = (KScreenWidth - 47) / 2
        let font = UIFont.PFSC_R(ofSize: 14) // 字体大小
        let maxWidth = width - 16 // 最大宽度限制
        // 创建NSAttributedString对象并设置属性
        let attributes = [NSAttributedString.Key.font : font] as [NSAttributedString.Key : Any]
        _ = NSMutableAttributedString(string: text, attributes: attributes)
        // 根据指定的最大宽度和字体大小计算文本的高度
        let size = (text as NSString).boundingRect(with: CGSize(width: maxWidth, height: .greatestFiniteMagnitude), options: .usesLineFragmentOrigin, attributes: attributes, context: nil).size
        var textHeight = size.height
        if textHeight > 40 {
            textHeight = 40
        }
        let imageSize = getImageSize(model.img_url)
        var imageHeight = 0.0
        if imageSize.width == 0 {
            imageHeight = width
        } else {
            imageHeight = width * imageSize.height/imageSize.width
            if imageHeight > 280 {
                imageHeight = 280
            }
        }
        let totalHeight = imageHeight + textHeight + 46
        return CGSize(width: width, height: totalHeight)
        
//        let margin = 20.0
//        let gap = 7.0
//        let itemWidth = ceil((KScreenWidth - 2*margin - gap)/2.0)
//        let arrItemH : [CGFloat] = [100,150,200,250,300,350,400]
//
//        let HHH = arrItemH[Int.random(in: 0...6)]
//        return CGSize(width: itemWidth, height: HHH)
    }
}
